==> medusa-0.2.2.tar.gz: medusa-0.2.2/libmedusa/medusa-index-service.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */

/*
 *  Medusa
 * 
 *  Copyright (C) 2000 Eazel, Inc.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Authors: Rebecca Schulman <rebecka@eazel.com>
 *  
 */


/* medusa-index-service.h -- API for externals users of the medusa
   indexing service. */

#ifndef MEDUSA_INDEX_SERVICE_H
#define MEDUSA_INDEX_SERVICE_H

#include <time.h>



typedef enum {
  MEDUSA_INDEXER_REQUEST_OK,
  MEDUSA_INDEXER_ERROR_BUSY,
  MEDUSA_INDEXER_ERROR_NO_RESPONSE,
  MEDUSA_INDEXER_ERROR_NO_INDEXER_PRESENT
} MedusaIndexingRequestResult;

/* Returns TRUE if index request was accepted */
MedusaIndexingRequestResult medusa_index_service_request_reindex                (void);

/* Returns 0 if getting the index time fails */
time_t                      medusa_index_service_get_last_index_update_time     (void);


#endif /* MEDUSA_INDEX_SERVICE_H */

==> medusa-0.3.2.tar.gz: medusa-0.3.2/libmedusa/medusa-index-service.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */

/*
 *  Medusa
 * 
 *  Copyright (C) 2000 Eazel, Inc.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Authors: Rebecca Schulman <rebecka@eazel.com>
 *  
 */


/* medusa-index-service.h -- API for externals users of the medusa
   indexing service. */

#ifndef MEDUSA_INDEX_SERVICE_H
#define MEDUSA_INDEX_SERVICE_H

#include <time.h>


typedef enum {
        MEDUSA_INDEXER_REQUEST_OK,
        MEDUSA_INDEXER_ERROR_BUSY,
        MEDUSA_INDEXER_ERROR_NO_RESPONSE,
        MEDUSA_INDEXER_ERROR_INVALID_RESPONSE,
} MedusaIndexingRequestResult;

typedef enum {
        MEDUSA_INDEXER_READY_TO_INDEX,
        MEDUSA_INDEXER_ALREADY_INDEXING,
        MEDUSA_INDEXER_NOT_AVAILABLE,
} MedusaIndexingStatus;

/* Returns TRUE if index request was accepted */
MedusaIndexingRequestResult medusa_index_service_request_reindex                (void);

/* Request whether the index service is currently available */
MedusaIndexingStatus        medusa_index_service_is_available                   (void);

/* Returns 0 if getting the index time fails */
time_t                      medusa_index_service_get_last_index_update_time     (void);


#endif /* MEDUSA_INDEX_SERVICE_H */
